
From: "Randy.Dunlap" <rddunlap@osdl.org>

Fix gcc printk arg type and other function parameter warnings:

drivers/usb/misc/sisusbvga/sisusb.c: In function `sisusb_send_packet':
drivers/usb/misc/sisusbvga/sisusb.c:583: warning: passing arg 7 of `sisusb_send_bulk_msg' from incompatible pointer type
drivers/usb/misc/sisusbvga/sisusb.c:591: warning: passing arg 6 of `sisusb_recv_bulk_msg' from incompatible pointer type
drivers/usb/misc/sisusbvga/sisusb.c: In function `sisusb_send_bridge_packet':
drivers/usb/misc/sisusbvga/sisusb.c:620: warning: passing arg 7 of `sisusb_send_bulk_msg' from incompatible pointer type
drivers/usb/misc/sisusbvga/sisusb.c:628: warning: passing arg 6 of `sisusb_recv_bulk_msg' from incompatible pointer type
drivers/usb/misc/sisusbvga/sisusb.c: In function `sisusb_write_mem_bulk':
drivers/usb/misc/sisusbvga/sisusb.c:989: warning: int format, different type arg (arg 3)
drivers/usb/misc/sisusbvga/sisusb.c:989: warning: int format, different type arg (arg 3)
drivers/usb/misc/sisusbvga/sisusb.c: In function `sisusb_clear_vram':
drivers/usb/misc/sisusbvga/sisusb.c:1407: warning: passing arg 7 of `sisusb_write_mem_bulk' from incompatible pointer type

Signed-off-by: Randy Dunlap <rddunlap@osdl.org>
Acked-by: Thomas Winischhofer <thomas@winischhofer.net>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/usb/misc/sisusbvga/sisusb.c |    9 +++++----
 1 files changed, 5 insertions(+), 4 deletions(-)

diff -puN drivers/usb/misc/sisusbvga/sisusb.c~sisusb-fix-arg-types drivers/usb/misc/sisusbvga/sisusb.c
--- 25/drivers/usb/misc/sisusbvga/sisusb.c~sisusb-fix-arg-types	2005-03-14 18:34:15.000000000 -0800
+++ 25-akpm/drivers/usb/misc/sisusbvga/sisusb.c	2005-03-14 18:34:15.000000000 -0800
@@ -564,7 +564,7 @@ static int sisusb_send_packet(struct sis
 						struct sisusb_packet *packet)
 {
 	int ret;
-	int bytes_transferred = 0;
+	ssize_t bytes_transferred = 0;
 	__le32 tmp;
 
 	if (len == 6)
@@ -601,7 +601,7 @@ static int sisusb_send_bridge_packet(str
 					unsigned int tflags)
 {
 	int ret;
-	int bytes_transferred = 0;
+	ssize_t bytes_transferred = 0;
 	__le32 tmp;
 
 	if (len == 6)
@@ -983,7 +983,7 @@ static int sisusb_write_mem_bulk(struct 
 				msgcount++;
 				if (msgcount < 500)
 					printk(KERN_ERR
-						"sisusbvga[%d]: Wrote %d of "
+						"sisusbvga[%d]: Wrote %Zd of "
 						"%d bytes, error %d\n",
 						sisusb->minor, *bytes_written,
 						length, ret);
@@ -1381,7 +1381,8 @@ sisusb_read_pci_config(struct sisusb_usb
 static int
 sisusb_clear_vram(struct sisusb_usb_data *sisusb, u32 address, int length)
 {
-	int ret, i, j;
+	int ret, i;
+	ssize_t j;
 
 	if (address < sisusb->vrambase)
 		return 1;
_
